*SOILS: HC27 Generic Soil Profiles by HarvestChoice (Last Modified: 1 February, 2013)
!
! AUTHORS
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! Jawoo Koo (International Food Policy Research Institute, Washington, DC, USA; j.koo@cgiar.org)
! John Dimes (Agri-Science. Queensland, DEEDI, Australia)
!
!
! ABOUT
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! The HC27 Soil Profile Database consists of generic soil profiles developed by John Dimes and 
! Jawoo Koo*. The 27 soil profiles were generated based on three criteria that crop models are most 
! responsive to: texture, rooting depth (proxy of water availability), and organic carbon content 
! (proxy of fertility). Three levels for each category were classified using the boundary conditions 
! based on the meta-analysis of WISE 1.1 soil profiles measured at crop land areas in Sub-Saharan 
! Africa (see Appendix B and C). 
!

!
! HOW TO USE
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! There are multiple ways to utilize these generic soil profiles in crop modeling applications, 
! especially when soil measurement data is not available for the study site. For example, 1) users can 
! choose the one that best matches the soil typically found in the study area by following the 
! decision tree of three multiple-choice questions (see Appendix A) and use it as a starting point, or
! 2) users can run models with all 27 soil profiles for a given study site to create a possible range 
! of simulation results, which can be narrowed down later as more site-specific information becomes 
! available. 
!
!
! LIMITATION
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! These generic soil profiles does not replace existing soil mapping efforts nor site-specific soil 
! measurements. Instead, this approach addresses the need for a set of reasonably representative and
! prototypical soil profiles in certain types of crop modeling applications (e.g., global-scale 
! modeling studies). Due to the nature of being *generic*, there will be applications for which the 
! use of HC27 is not desirable, especially where detailed soil property dynamics beyond the three 
! criteria are emphasized.
!
! 
! LEARN MORE
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
! HarvestChoice Labs at https://urldefense.proofpoint.com/v1/url?u=http://harvestchoice.org/labs/hc27-genericprototypical-soil-profiles&k=EWEYHnIvm0nsSxnW5y9VIw%3D%3D%0A&r=GmObmj8mAd7pF8UOxO9gnadtxEHELcqxEHMuyaAtAz8%3D%0A&m=GDQyh9RVHa5L%2BZzHyPwdcIFGXylCDT5ZSxmsS1WvhNU%3D%0A&s=c154649d2597c5cfcc49faf48ae8eca3062f218047064025d4570e8ebdbe7f9c
!
! HOW TO CITE
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
! Koo, Jawoo; Dimes, John, 2013, "HC27 Generic Soil Profile Database", 
! https://urldefense.proofpoint.com/v1/url?u=http://hdl.handle.net/1902.1/20299&k=EWEYHnIvm0nsSxnW5y9VIw%3D%3D%0A&r=GmObmj8mAd7pF8UOxO9gnadtxEHELcqxEHMuyaAtAz8%3D%0A&m=GDQyh9RVHa5L%2BZzHyPwdcIFGXylCDT5ZSxmsS1WvhNU%3D%0A&s=1ade1328dd35653488a5907f086c5220c5fac4692ee6af20966d43eea1e4eccb, Harvard Dataverse, V2
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
!
! APPENDIX A. DECISION TREE
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!      TEXTURE -- FERTILITY - DEPTH --- SOILPROILE
!      ===========================================
!      +- CLAY -+- HIGH ---+- DEEP ---- HC_GEN0001
!      |        |          +- MEDIUM -- HC_GEN0002
!      |        |          +- SHALLOW - HC_GEN0003
!      |        +- MEDIUM -+- DEEP ---- HC_GEN0004
!      |        |          +- MEDIUM -- HC_GEN0005
!      |        |          +- SHALLOW - HC_GEN0006
!      |        +- LOW ----+- DEEP ---- HC_GEN0007
!      |                   +- MEDIUM -- HC_GEN0008
!      |                   +- SHALLOW - HC_GEN0009
!      +- LOAM -+- HIGH ---+- DEEP ---- HC_GEN0010 
!      |        |          +- MEDIUM -- HC_GEN0011
!      |        |          +- SHALLOW - HC_GEN0012
!      |        +- MEDIUM -+- DEEP ---- HC_GEN0013
!      |        |          +- MEDIUM -- HC_GEN0014
!      |        |          +- SHALLOW - HC_GEN0015
!      |        +- LOW ----+- DEEP ---- HC_GEN0016
!      |                   +- MEDIUM -- HC_GEN0017
!      |                   +- SHALLOW - HC_GEN0018
!      +- SAND -+- HIGH ---+- DEEP ---- HC_GEN0019 
!               |          +- MEDIUM -- HC_GEN0020
!               |          +- SHALLOW - HC_GEN0021
!               +- MEDIUM -+- DEEP ---- HC_GEN0022
!               |          +- MEDIUM -- HC_GEN0023
!               |          +- SHALLOW - HC_GEN0024
!               +- LOW ----+- DEEP ---- HC_GEN0025
!                          +- MEDIUM -- HC_GEN0026
!                          +- SHALLOW - HC_GEN0027
!
!
! APPENDIX B. BOUNDARY CONDITION: FERTILITY, %[SOC of TOP SOIL]
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! HIGH: 1.2 <= SOC
! MED:  0.7 <= SOC < 1.2
! LOW:  0.0 <= SOC < 0.7
!
!
! APPENDIX C. BOUNDARY CONDITION: ROOTING DEPTH, cm
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! DEEP:   150 <= ROOTING DEPTH
! MEDIUM:  90 <= ROOTING DEPTH < 150
! SHALLOW:  0 <= ROOTING DEPTH < 90
!
! ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

!---------+
! C L A Y |___________________________________________________________________________________________
!---------+

*HC_GEN0001  IFPRI       C       180 HarvestChoice HC27, Clay HF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Deep (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.40 60.00 25.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.87 60.00 25.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.69 60.00 25.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.63 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.60 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   150   BC2 0.360 0.430 0.480  0.08  0.30  1.20  0.53 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   180     C 0.400 0.430 0.480  0.03  0.20  1.20  0.30 60.00 25.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0002  IFPRI       C       120 HarvestChoice HC27, Clay HF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Medm (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.40 60.00 25.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.87 60.00 25.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.69 60.00 25.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.63 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.60 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0003  IFPRI       C       060 HarvestChoice HC27, Clay HF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Shal (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.40 60.00 25.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.87 60.00 25.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.69 60.00 25.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0004  IFPRI       C       180 HarvestChoice HC27, Clay MF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Deep (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.00 60.00 25.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.62 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.49 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.45 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.43 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   150   BC2 0.360 0.430 0.480  0.08  0.30  1.20  0.38 60.00 25.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
   180     C 0.400 0.430 0.480  0.03  0.20  1.20  0.21 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0005  IFPRI       C       120 HarvestChoice HC27, Clay MF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Medm (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.00 60.00 25.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.62 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.49 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.45 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.43 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0006  IFPRI       C       060 HarvestChoice HC27, Clay MF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Shal (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  1.00 60.00 25.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.62 60.00 25.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.49 60.00 25.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0007  IFPRI       C       180 HarvestChoice HC27, Clay LF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Deep (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  0.40 60.00 25.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.25 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.20 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.18 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.17 60.00 25.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   150   BC2 0.360 0.430 0.480  0.08  0.30  1.20  0.15 60.00 25.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   180     C 0.400 0.430 0.480  0.03  0.20  1.20  0.09 60.00 25.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0008  IFPRI       C       120 HarvestChoice HC27, Clay LF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Medm (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  0.40 60.00 25.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.25 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.20 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.290 0.420 0.470  0.22  0.50  1.20  0.18 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.320 0.425 0.475  0.12  0.40  1.20  0.17 60.00 25.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0009  IFPRI       C       060 HarvestChoice HC27, Clay LF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Clay Shal (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.05  8.00  0.20 85.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.210 0.390 0.440  1.00  1.00  1.20  0.40 60.00 25.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.230 0.410 0.467  0.65  0.80  1.20  0.25 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.260 0.415 0.467  0.38  0.60  1.20  0.20 60.00 25.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

!---------+
! L O A M |____________________________________________________________________________________________
!---------+

*HC_GEN0010  IFPRI       L       180 HarvestChoice HC27, Loam HF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Deep (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.40 30.00 45.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.87 30.00 45.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.69 30.00 45.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.63 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.60 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   150   BC2 0.270 0.320 0.440  0.30  1.30  1.40  0.53 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   180     C 0.290 0.325 0.440  0.10  1.20  1.40  0.30 30.00 45.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0011  IFPRI       L       120 HarvestChoice HC27, Loam HF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Medm (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.40 30.00 45.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.87 30.00 45.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.69 30.00 45.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.63 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.60 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0012  IFPRI       L       060 HarvestChoice HC27, Loam HF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Shal (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.40 30.00 45.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.87 30.00 45.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.69 30.00 45.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0013  IFPRI       L       180 HarvestChoice HC27, Loam MF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Deep (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.00 30.00 45.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.62 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.49 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.45 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.43 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   150   BC2 0.270 0.320 0.440  0.30  1.30  1.40  0.38 30.00 45.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
   180     C 0.290 0.325 0.440  0.10  1.20  1.40  0.21 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0014  IFPRI       L       120 HarvestChoice HC27, Loam MF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Medm (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.00 30.00 45.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.62 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.49 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.45 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.43 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0015  IFPRI       L       060 HarvestChoice HC27, Loam MF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Shal (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  1.00 30.00 45.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.62 30.00 45.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.49 30.00 45.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0016  IFPRI       L       180 HarvestChoice HC27, Loam LF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Deep (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  0.40 30.00 45.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.25 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.20 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.18 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.17 30.00 45.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   150   BC2 0.270 0.320 0.440  0.30  1.30  1.40  0.15 30.00 45.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   180     C 0.290 0.325 0.440  0.10  1.20  1.40  0.09 30.00 45.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0017  IFPRI       L       120 HarvestChoice HC27, Loam LF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Medm (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  0.40 30.00 45.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.25 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.20 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.215 0.315 0.430  0.40  1.50  1.40  0.18 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.250 0.317 0.440  0.30  1.40  1.40  0.17 30.00 45.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0018  IFPRI       L       060 HarvestChoice HC27, Loam LF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Loam Shal (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.10  6.00  0.50 75.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.170 0.301 0.400  1.00  4.00  1.40  0.40 30.00 45.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.180 0.310 0.410  0.70  1.80  1.40  0.25 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.190 0.310 0.420  0.50  1.60  1.40  0.20 30.00 45.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

!---------+
! S A N D |____________________________________________________________________________________________
!---------+

*HC_GEN0019  IFPRI       S       180 HarvestChoice HC27, Sand HF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Deep (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.40  5.00  3.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.87  5.00  3.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.69  5.00  3.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.63  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.60  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   150   BC2 0.150 0.194 0.370  0.30  8.30  1.60  0.53  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   180     C 0.180 0.207 0.370  0.20  8.20  1.60  0.30  5.00  3.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0020  IFPRI       S       120 HarvestChoice HC27, Sand HF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Medm (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.40  5.00  3.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.87  5.00  3.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.69  5.00  3.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.63  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.60  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0021  IFPRI       S       060 HarvestChoice HC27, Sand HF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Shal (HF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.40  5.00  3.00 -99.0  0.12  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.87  5.00  3.00 -99.0  0.07  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.69  5.00  3.00 -99.0  0.06  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0022  IFPRI       S       180 HarvestChoice HC27, Sand MF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Deep (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.00  5.00  3.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.62  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.49  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.45  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.43  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   150   BC2 0.150 0.194 0.370  0.30  8.30  1.60  0.38  5.00  3.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
   180     C 0.180 0.207 0.370  0.20  8.20  1.60  0.21  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0023  IFPRI       S       120 HarvestChoice HC27, Sand MF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Medm (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.00  5.00  3.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.62  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.49  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.45  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.43  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0024  IFPRI       S       060 HarvestChoice HC27, Sand MF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Shal (MF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  1.00  5.00  3.00 -99.0  0.08  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.62  5.00  3.00 -99.0  0.05  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.49  5.00  3.00 -99.0  0.04  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0025  IFPRI       S       180 HarvestChoice HC27, Sand LF180
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Deep (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  0.40  5.00  3.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.25  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.20  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.18  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.17  5.00  3.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   150   BC2 0.150 0.194 0.370  0.30  8.30  1.60  0.15  5.00  3.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
   180     C 0.180 0.207 0.370  0.20  8.20  1.60  0.09  5.00  3.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   150 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   180 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0026  IFPRI       S       120 HarvestChoice HC27, Sand LF120
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Medm (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  0.40  5.00  3.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.25  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.20  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    90     B 0.110 0.175 0.370  0.50  8.50  1.60  0.18  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
   120   BC1 0.130 0.180 0.370  0.40  8.40  1.60  0.17  5.00  3.00 -99.0  0.01  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    90 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
   120 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0

*HC_GEN0027  IFPRI       S       060 HarvestChoice HC27, Sand LF060
@SITE        COUNTRY          LAT     LONG SCS Family
 -99         Generic      -00.000  -00.000 Sand Shal (LF)
@ SCOM  SALB  SLU1  SLDR  SLRO  SLNF  SLPF  SMHB  SMPX  SMKE
    BK  0.15  4.00  0.75 65.00  1.00  1.00 SA001 SA001 SA001
@  SLB  SLMH  SLLL  SDUL  SSAT  SRGF  SSKS  SBDM  SLOC  SLCL  SLSI  SLCF  SLNI  SLHW  SLHB  SCEC  SADC
    10     A 0.060 0.165 0.360  1.00 10.00  1.60  0.40  5.00  3.00 -99.0  0.03  6.50 -99.0 -99.0 -99.0
    30    AB 0.070 0.170 0.365  0.80  8.80  1.60  0.25  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
    60    BA 0.090 0.172 0.370  0.60  8.60  1.60  0.20  5.00  3.00 -99.0  0.02  6.50 -99.0 -99.0 -99.0
@  SLB  SLPX  SLPT  SLPO CACO3  SLAL  SLFE  SLMN  SLBS  SLPA  SLPB  SLKE  SLMG  SLNA  SLSU  SLEC  SLCA
    10 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    30 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
    60 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0 -99.0
